==> bear_1.0.0.tar.gz: bear/R/zzz.R <==
.First.lib <- function(...) {

# echo output to screen
cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                                                                          *\n")
cat("*                                  bear                                    *\n")
cat("*                                v 1.0.0                                   *\n")   
cat("*                                                                          *\n")   
cat("* This package is used to analyze average bioequivalence(BE) data.         *\n")
cat("* The statistical procedures with this package use a two-treatment         *\n")
cat("* crossover design.  The statistical analysis for bioequivalence parameters*\n") 
cat("* (AUCs and Cmax) are based on the two one-sided tests.  Average BE        *\n")
cat("* involves the calculation of a 90% confidence interval(CI) for the ratio  *\n")
cat("* of the averages of the measures for the test and reference products. The *\n")
cat("* BE will be established when the calculated CIs fall within a BE limit    *\n")
cat("* (80-125% for the ratio of the product averages).  Bioavailability data   *\n")
cat("* analysis do the same procedures without GLM analysis.                    *\n")
cat("*                                                                          *\n")                
cat("* The following steps will be conducted as follows:                        *\n")
cat("* ->1: Sample size estimation for average BE                               *\n")
cat("* ->2: Noncompartment Analysis (NCA)                                       *\n")
cat("* ->3: Generalized Linear Models (GLM)                                     *\n")
cat("*                                                                          *\n")   
cat("*                                                                          *\n")
cat("*                  Please type 'go()' to get started.                      *\n")
cat("*                                                                          *\n")
cat("****************************************************************************\n")
  
}

==> bear_1.1.2.tar.gz: bear/R/zzz.R <==
.First.lib <- function(...) {

# echo output to screen
cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                                                                          *\n")
cat("*                                  bear                                    *\n")
cat("*                                v 1.1.2                                   *\n")   
cat("*                                                                          *\n")   
cat("* This package is used to analyze average bioequivalence (ABE) data.       *\n")
cat("* The statistical procedures with this package use a two-treatment         *\n")
cat("* crossover design.  The statistical analysis for bioequivalence parameters*\n") 
cat("* (AUCs and Cmax) are based on the two one-sided tests.  Average BE        *\n")
cat("* involves the calculation of a 90% confidence interval (CI) for the ratio *\n")
cat("* of the averages of the measures for the test and reference products. The *\n")
cat("* BE will be established when the calculated CIs fall within the range of  *\n")
cat("* (80-125% for the ratio of the product averages).  Bioavailability data   *\n")
cat("* analyses go through the same procedures except ANOVA (lm) analysis.      *\n")
cat("*                                                                          *\n")                
cat("* The following steps will be conducted as follows:                        *\n")
cat("* ->1: Sample size estimation for average BE                               *\n")
cat("* ->2: Noncompartmental Analysis (NCA)                                     *\n")
cat("* ->3: ANOVA (lm)                                                          *\n")
cat("*                                                                          *\n")   
cat("*                                                                          *\n")
cat("*                  Please type 'go()' to get started.                      *\n")
cat("*                                                                          *\n")
cat("****************************************************************************\n")
  
}
